dot-realgm_pick: Internal: pick the best data table from a list of RealGM...

.realgm_pickR Documentation

Internal: pick the best data table from a list of RealGM tables

Description

Chooses the table containing all must_have columns (when supplied) with the most rows; otherwise the table with the most rows.

Usage

.realgm_pick(tables, must_have = NULL)

Arguments

tables

A list of data.frames, e.g. from .realgm_tables().

must_have

Optional character vector of required column names.

Value

A single data.frame, or NULL if tables is empty.


hoopR documentation built on Aug. 25, 2026, 9:07 a.m.