espn_mbb_award: *Get ESPN MBB Season Award Detail*

View source: R/espn_mbb_awards.R

espn_mbb_awardR Documentation

Get ESPN MBB Season Award Detail

Description

Returns the name, description, and winners of one MBB season award.

Returns the name, description, and winners of one NBA season award. Most awards have a single winner; multi-recipient awards (e.g. All-NBA First Team) return one row per winner.

Usage

espn_mbb_award(award_id, season = most_recent_mbb_season(), ...)

espn_nba_award(award_id, season = most_recent_nba_season(), ...)

Arguments

award_id

ESPN award identifier (character or numeric).

season

Season year (numeric). Defaults to the most recent MBB season.

...

Additional arguments; currently unused.

Value

A tibble with one row per winner.

col_name types description
league character League slug.
season integer Season year.
award_id character ESPN award identifier.
name character Award name.
description character Award description.
athlete_id character ESPN athlete id of winner.
team_id character ESPN team id.
athlete_ref character ⁠$ref⁠ to winner's per-season athlete resource.
team_ref character ⁠$ref⁠ to winner's per-season team resource.

A tibble with one row per winner.

col_name types description
league character League slug ("nba").
season integer Season year.
award_id character ESPN award identifier.
name character Award name (e.g. "MVP").
description character Award description.
athlete_id character ESPN athlete id of winner (parsed from athlete_ref).
team_id character ESPN team id (parsed from team_ref).
athlete_ref character ⁠$ref⁠ to winner's per-season athlete resource.
team_ref character ⁠$ref⁠ to winner's per-season team resource.

Author(s)

Saiem Gilani

See Also

Other ESPN MBB Functions: espn_mbb_athletes_index(), espn_mbb_calendar(), espn_mbb_coach(), espn_mbb_coach_record(), espn_mbb_coach_season(), espn_mbb_coaches(), espn_mbb_conferences(), espn_mbb_franchise(), espn_mbb_franchises(), espn_mbb_futures(), espn_mbb_game_all(), espn_mbb_game_odds(), espn_mbb_game_official_detail(), espn_mbb_game_play(), espn_mbb_game_play_personnel(), espn_mbb_game_player_box(), espn_mbb_game_probabilities(), espn_mbb_game_propbets(), espn_mbb_game_team_linescores(), espn_mbb_game_team_roster_entry(), espn_mbb_injuries(), espn_mbb_leaders(), espn_mbb_news(), espn_mbb_player_awards(), espn_mbb_player_career_stats(), espn_mbb_player_eventlog_v2(), espn_mbb_player_info(), espn_mbb_player_overview(), espn_mbb_player_seasons(), espn_mbb_player_stats(), espn_mbb_position(), espn_mbb_positions(), espn_mbb_powerindex(), espn_mbb_rankings(), espn_mbb_scoreboard(), espn_mbb_season_awards(), espn_mbb_season_group(), espn_mbb_season_groups(), espn_mbb_season_info(), espn_mbb_season_leaders(), espn_mbb_season_ranking(), espn_mbb_season_rankings(), espn_mbb_season_type(), espn_mbb_season_types(), espn_mbb_season_week(), espn_mbb_season_weeks(), espn_mbb_seasons(), espn_mbb_standings(), espn_mbb_team(), espn_mbb_team_current_roster(), espn_mbb_team_injuries(), espn_mbb_team_news(), espn_mbb_team_odds_records(), espn_mbb_team_record(), espn_mbb_team_record_detail(), espn_mbb_team_schedule(), espn_mbb_team_season_roster(), espn_mbb_team_season_statistics(), espn_mbb_team_stats(), espn_mbb_teams(), espn_mbb_tournament(), espn_mbb_tournament_season(), espn_mbb_tournament_seasons(), espn_mbb_tournaments(), espn_mbb_venues(), espn_mbb_week_ranking(), espn_mbb_week_rankings(), espn_mbb_wp()

Other ESPN NBA Functions: espn_mbb_athletes_index(), espn_mbb_calendar(), espn_mbb_coach(), espn_mbb_coach_record(), espn_mbb_coach_season(), espn_mbb_coaches(), espn_mbb_conferences(), espn_mbb_franchise(), espn_mbb_franchises(), espn_mbb_futures(), espn_mbb_game_all(), espn_mbb_game_odds(), espn_mbb_game_official_detail(), espn_mbb_game_play(), espn_mbb_game_play_personnel(), espn_mbb_game_player_box(), espn_mbb_game_probabilities(), espn_mbb_game_propbets(), espn_mbb_game_team_linescores(), espn_mbb_game_team_roster_entry(), espn_mbb_injuries(), espn_mbb_leaders(), espn_mbb_news(), espn_mbb_player_awards(), espn_mbb_player_career_stats(), espn_mbb_player_eventlog_v2(), espn_mbb_player_info(), espn_mbb_player_overview(), espn_mbb_player_seasons(), espn_mbb_player_stats(), espn_mbb_position(), espn_mbb_positions(), espn_mbb_powerindex(), espn_mbb_scoreboard(), espn_mbb_season_awards(), espn_mbb_season_group(), espn_mbb_season_groups(), espn_mbb_season_info(), espn_mbb_season_leaders(), espn_mbb_season_ranking(), espn_mbb_season_rankings(), espn_mbb_season_type(), espn_mbb_season_types(), espn_mbb_season_week(), espn_mbb_season_weeks(), espn_mbb_seasons(), espn_mbb_standings(), espn_mbb_team(), espn_mbb_team_current_roster(), espn_mbb_team_injuries(), espn_mbb_team_news(), espn_mbb_team_odds_records(), espn_mbb_team_record(), espn_mbb_team_record_detail(), espn_mbb_team_schedule(), espn_mbb_team_season_roster(), espn_mbb_team_season_statistics(), espn_mbb_team_stats(), espn_mbb_teams(), espn_mbb_tournament(), espn_mbb_tournament_season(), espn_mbb_tournament_seasons(), espn_mbb_tournaments(), espn_mbb_venues(), espn_mbb_week_ranking(), espn_mbb_week_rankings(), espn_mbb_wp(), espn_nba_draft_pick(), espn_nba_freeagents(), espn_nba_player_contracts(), espn_nba_team_depthchart(), espn_nba_transactions()

Examples


  espn_mbb_award(award_id = 344, season = 2024)


  # MVP award id = 33
  espn_nba_award(award_id = 33, season = 2024)


hoopR documentation built on Aug. 25, 2026, 9:07 a.m.