Returns a single-row tibble for one referee assigned to one MBB event,
with their name, position (Referee / Crew Chief / Umpire), and crew
order. Pair with espn_mbb_game_officials() to enumerate the crew.
Returns a single-row tibble for one referee assigned to one NBA event,
with their name, position (Referee / Crew Chief / Umpire), and crew
order. Pair with espn_nba_game_officials() to enumerate the crew.
espn_mbb_game_official_detail(event_id, order, ...)espn_nba_game_official_detail(event_id, order, ...)
A single-row tibble.
A single-row tibble.
ESPN event identifier.
Crew order index (1 = first official). Pair with the order column from event_officials().
Additional arguments; currently unused.
Saiem Gilani
Other ESPN MBB Functions:
espn_mbb_athletes_index(),
espn_mbb_award(),
espn_mbb_calendar(),
espn_mbb_coach(),
espn_mbb_coach_record(),
espn_mbb_coach_season(),
espn_mbb_coaches(),
espn_mbb_conferences(),
espn_mbb_franchise(),
espn_mbb_franchises(),
espn_mbb_futures(),
espn_mbb_game_all(),
espn_mbb_game_odds(),
espn_mbb_game_play(),
espn_mbb_game_play_personnel(),
espn_mbb_game_player_box(),
espn_mbb_game_probabilities(),
espn_mbb_game_propbets(),
espn_mbb_game_team_linescores(),
espn_mbb_game_team_roster_entry(),
espn_mbb_injuries(),
espn_mbb_leaders(),
espn_mbb_news(),
espn_mbb_player_awards(),
espn_mbb_player_career_stats(),
espn_mbb_player_eventlog_v2(),
espn_mbb_player_info(),
espn_mbb_player_overview(),
espn_mbb_player_seasons(),
espn_mbb_player_stats(),
espn_mbb_position(),
espn_mbb_positions(),
espn_mbb_powerindex(),
espn_mbb_rankings(),
espn_mbb_scoreboard(),
espn_mbb_season_awards(),
espn_mbb_season_group(),
espn_mbb_season_groups(),
espn_mbb_season_info(),
espn_mbb_season_leaders(),
espn_mbb_season_ranking(),
espn_mbb_season_rankings(),
espn_mbb_season_type(),
espn_mbb_season_types(),
espn_mbb_season_week(),
espn_mbb_season_weeks(),
espn_mbb_seasons(),
espn_mbb_standings(),
espn_mbb_team(),
espn_mbb_team_current_roster(),
espn_mbb_team_injuries(),
espn_mbb_team_news(),
espn_mbb_team_odds_records(),
espn_mbb_team_record(),
espn_mbb_team_record_detail(),
espn_mbb_team_schedule(),
espn_mbb_team_season_roster(),
espn_mbb_team_season_statistics(),
espn_mbb_team_stats(),
espn_mbb_teams(),
espn_mbb_tournament(),
espn_mbb_tournament_season(),
espn_mbb_tournament_seasons(),
espn_mbb_tournaments(),
espn_mbb_venues(),
espn_mbb_week_ranking(),
espn_mbb_week_rankings(),
espn_mbb_wp()
Other ESPN NBA Functions:
espn_mbb_athletes_index(),
espn_mbb_award(),
espn_mbb_calendar(),
espn_mbb_coach(),
espn_mbb_coach_record(),
espn_mbb_coach_season(),
espn_mbb_coaches(),
espn_mbb_conferences(),
espn_mbb_franchise(),
espn_mbb_franchises(),
espn_mbb_futures(),
espn_mbb_game_all(),
espn_mbb_game_odds(),
espn_mbb_game_play(),
espn_mbb_game_play_personnel(),
espn_mbb_game_player_box(),
espn_mbb_game_probabilities(),
espn_mbb_game_propbets(),
espn_mbb_game_team_linescores(),
espn_mbb_game_team_roster_entry(),
espn_mbb_injuries(),
espn_mbb_leaders(),
espn_mbb_news(),
espn_mbb_player_awards(),
espn_mbb_player_career_stats(),
espn_mbb_player_eventlog_v2(),
espn_mbb_player_info(),
espn_mbb_player_overview(),
espn_mbb_player_seasons(),
espn_mbb_player_stats(),
espn_mbb_position(),
espn_mbb_positions(),
espn_mbb_powerindex(),
espn_mbb_scoreboard(),
espn_mbb_season_awards(),
espn_mbb_season_group(),
espn_mbb_season_groups(),
espn_mbb_season_info(),
espn_mbb_season_leaders(),
espn_mbb_season_ranking(),
espn_mbb_season_rankings(),
espn_mbb_season_type(),
espn_mbb_season_types(),
espn_mbb_season_week(),
espn_mbb_season_weeks(),
espn_mbb_seasons(),
espn_mbb_standings(),
espn_mbb_team(),
espn_mbb_team_current_roster(),
espn_mbb_team_injuries(),
espn_mbb_team_news(),
espn_mbb_team_odds_records(),
espn_mbb_team_record(),
espn_mbb_team_record_detail(),
espn_mbb_team_schedule(),
espn_mbb_team_season_roster(),
espn_mbb_team_season_statistics(),
espn_mbb_team_stats(),
espn_mbb_teams(),
espn_mbb_tournament(),
espn_mbb_tournament_season(),
espn_mbb_tournament_seasons(),
espn_mbb_tournaments(),
espn_mbb_venues(),
espn_mbb_week_ranking(),
espn_mbb_week_rankings(),
espn_mbb_wp(),
espn_nba_draft_pick(),
espn_nba_freeagents(),
espn_nba_player_contracts(),
espn_nba_team_depthchart(),
espn_nba_transactions()
# \donttest{
espn_mbb_game_official_detail(event_id = 401256760, order = 1)
# }
# \donttest{
espn_nba_game_official_detail(event_id = 401283399, order = 1)
# }
Run the code above in your browser using DataLab