espn_mbb_player_stats: *Get ESPN men's college basketball player stats data*

espn_mbb_player_statsR Documentation

Get ESPN men's college basketball player stats data

Description

Get ESPN men's college basketball player stats data

Get ESPN NBA player stats data

Usage

espn_mbb_player_stats(athlete_id, year, season_type = "regular", total = FALSE)

espn_nba_player_stats(athlete_id, year, season_type = "regular", total = FALSE)

Arguments

athlete_id

Athlete ID

year

Year

season_type

(character, default: regular): Season type - regular or postseason

total

(boolean, default: FALSE): Totals

Value

Returns a tibble with the player stats data

col_name types description
athlete_id integer Unique athlete identifier (ESPN).
athlete_uid character ESPN athlete UID (universal identifier).
athlete_guid character ESPN athlete GUID.
athlete_type character Athlete type / class.
sdr integer Sdr.
first_name character Player's first name.
last_name character Player's last name.
full_name character Player's full name.
display_name character Display name.
short_name character Short display name.
weight numeric Player weight in pounds.
display_weight character Player weight in display format (e.g. '180 lbs').
height numeric Player height (string e.g. '6-2' or inches).
display_height character Player height in display format (e.g. '6-2').
age integer Player age (in years).
date_of_birth character Date of birth (YYYY-MM-DD).
birth_place_city character Birth place city.
birth_place_state character Birth place state.
birth_place_country character Birth place country.
slug character URL-safe identifier.
headshot_href character Headshot image URL.
headshot_alt character Alternative-text label for the headshot.
jersey character Jersey number worn by the player.
position_id integer Unique position identifier.
position_name character Listed roster position ('Guard', 'Forward', 'Center').
position_display_name character Position display name.
position_abbreviation character Position abbreviation ('G' / 'F' / 'C').
position_leaf logical Position leaf.
linked logical TRUE if the record is linked to a related entity.
experience_years integer Experience years.
experience_display_value character Experience display value.
experience_abbreviation character Experience abbreviation.
active logical TRUE if the row represents an active record (player / team / season).
draft_display_text character Draft display text.
draft_round integer Round of the draft selection.
draft_year integer Draft year (4-digit).
draft_selection integer Draft selection.
status_id integer Status identifier.
status_name character Status label.
status_type character Status type.
status_abbreviation character Status abbreviation.
defensive_blocks numeric Short for blocked shot, number of times when a defensive player legally deflects a field goal attempt from an offensive player.
defensive_defensive_rebounds numeric The number of times when the defense obtains the possession of the ball after a missed shot by the offense.
defensive_steals numeric The number of times a defensive player forced a turnover by intercepting or deflecting a pass or a dribble of an offensive player.
defensive_turnover_points numeric The amount of points resulting from the possession following a turnover.
defensive_avg_defensive_rebounds numeric The average defensive rebounds per game.
defensive_avg_blocks numeric The average blocks per game.
defensive_avg_steals numeric The average steals per game.
general_disqualifications numeric The number of times a player reached the foul limit.
general_flagrant_fouls numeric The number of fouls that the officials thought were unnecessary or excessive.
general_fouls numeric The number of times a player had illegal contact with the opponent.
general_per numeric A numerical value for each of a player's accomplishments per-minute and is pace-adjusted for the team they play on. The league average in PER to 15.00 every season.
general_ejections numeric The number of times a player or coach is removed from the game as a result of a serious offense.
general_technical_fouls numeric The number of times an player or coach was called for a technical foul (unsportsmanlike conduct or violations).
general_rebounds numeric The total number of rebounds (offensive and defensive).
general_minutes numeric The total number of minutes played.
general_avg_minutes numeric The average number of minutes per game.
general_fantasy_rating numeric The Fantasy Rating of a player.
general_plus_minus numeric A player's estimated on-court impact on team performance measured in point differential per 100 possessions.
general_avg_rebounds numeric The average rebounds per game.
general_avg_fouls numeric The average fouls committed per game.
general_avg_flagrant_fouls numeric The average number of flagrant fouls per game.
general_avg_technical_fouls numeric The average number of technical fouls per game.
general_avg_ejections numeric The average ejections per game.
general_avg_disqualifications numeric The average number of disqualifications per game.
general_assist_turnover_ratio numeric The average number of assists a player or team records per turnover.
general_steal_foul_ratio numeric The average number of steals a player or team records per foul committed.
general_block_foul_ratio numeric The average number of blocks a player or record per foul committed.
general_avg_team_rebounds numeric The average number of rebounds for a team per game.
general_total_rebounds numeric The total number of rebounds for a team or player.
general_total_technical_fouls numeric The total number of technical fouls for a team or player.
general_steal_turnover_ratio numeric The number of steals per turnover.
general_games_played numeric Games Played.
general_games_started numeric The number of games started by an athlete.
general_double_double numeric The number of times double digit values were accumulated in 2 of the following categories: points, rebounds, assists, steals, and blocked shots.
general_triple_double numeric The number of times double digit values were accumulated in 3 of the following categories: points, rebounds, assists, steals, and blocked shots.
offensive_assists numeric The number of times a player who passes the ball to a teammate in a way that leads to a score by field goal, meaning that he or she was "assisting" in the basket. There is some judgment involved in deciding whether a passer should be credited with an assist.
offensive_field_goals numeric Field Goal makes and attempts.
offensive_field_goals_attempted numeric The number of times a 2pt field goal was attempted.
offensive_field_goals_made numeric The number of times a 2pt field goal was made.
offensive_field_goal_pct numeric The ratio of field goals made to field goals attempted: FGM / FGA.
offensive_free_throws numeric Free Throw makes and attempts.
offensive_free_throw_pct numeric The ratio of free throws made to free throws attempted: FTM / FTA.
offensive_free_throws_attempted numeric The number of times a free throw was attempted.
offensive_free_throws_made numeric The number of times a free throw was made.
offensive_offensive_rebounds numeric The number of times when the offense obtains the possession of the ball after a missed shot.
offensive_points numeric The number of points scored.
offensive_turnovers numeric The number of times a player loses possession to the other team.
offensive_three_point_field_goals_attempted numeric The number of times a 3pt field goal was attempted.
offensive_three_point_field_goals_made numeric The number of times a 3pt field goal was made.
offensive_total_turnovers numeric The number of turnovers plus team turnovers for the team.
offensive_points_in_paint numeric The amount of points scored in the area known as "the Paint"(the rectangle between the foul line and the baseline).
offensive_fast_break_points numeric The number of points scored on fast breaks.
offensive_avg_field_goals_made numeric The average field goals made per game.
offensive_avg_field_goals_attempted numeric The average field goals attempted per game.
offensive_avg_three_point_field_goals_made numeric The average three point field goals made per game.
offensive_avg_three_point_field_goals_attempted numeric The average three point field goals attempted per game.
offensive_avg_free_throws_made numeric The average free throw shots made per game.
offensive_avg_free_throws_attempted numeric The average free throw shots attempted per game.
offensive_avg_points numeric The average number of points scored per game.
offensive_avg_offensive_rebounds numeric The average offensive rebounds per game.
offensive_avg_assists numeric The average assists per game.
offensive_avg_turnovers numeric The average turnovers committed per game.
offensive_offensive_rebound_pct numeric The percentage of the number of times they obtain the possession of the ball after a missed shot.
offensive_estimated_possessions numeric An estimation of the number of possessions for a team or player.
offensive_avg_estimated_possessions numeric The average number of estimated possessions per game for a team or player.
offensive_points_per_estimated_possessions numeric The number of points per estimated possession for a team or player.
offensive_avg_team_turnovers numeric The average number of turnovers for a team per game.
offensive_avg_total_turnovers numeric The average number of total turnovers for a team per game.
offensive_three_point_field_goal_pct numeric The ratio of 3pt field goals made to 3pt field goals attempted: 3PM / 3PA.
offensive_two_point_field_goals_made numeric The number of 2-point field goals made for a team or player.
offensive_two_point_field_goals_attempted numeric The number of 2-point field goals attempted for a team or player.
offensive_avg_two_point_field_goals_made numeric The number of 2-point field goals made per game for a team or player.
offensive_avg_two_point_field_goals_attempted numeric The number of 2-point field goals attempted per game for a team or player.
offensive_two_point_field_goal_pct numeric The percentage of 2-points fields goals made by a team or player.
offensive_shooting_efficiency numeric The efficiency with which a team or player shoots the basketball.
offensive_scoring_efficiency numeric The efficiency with which a team or player scores the basketball.
team_id integer Unique team identifier.
team_guid character ESPN team GUID.
team_uid character ESPN universal team identifier (UID format 's:40~l:...~t:...').
team_sdr integer ESPN team SDR identifier.
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
team_location character Team city or location string.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_nickname character Team nickname.
team_abbreviation character Short team abbreviation (e.g. 'LAS').
team_display_name character Full team display name.
team_short_display_name character Short team display name (e.g. 'Aces').
team_color character Team primary color (hex without leading '#').
team_alternate_color character Team alternate color (hex without leading '#').
is_active logical Is active.
is_all_star logical Is all star.
logo_href character Team or league logo URL.
logo_dark_href character Logo URL for dark backgrounds.

Returns a tibble with the player stats data

col_name types description
athlete_id integer Unique athlete identifier (ESPN).
athlete_uid character ESPN athlete UID (universal identifier).
athlete_guid character ESPN athlete GUID.
athlete_type character Athlete type / class.
sdr integer Sdr.
first_name character Player's first name.
last_name character Player's last name.
full_name character Player's full name.
display_name character Display name.
short_name character Short display name.
weight numeric Player weight in pounds.
display_weight character Player weight in display format (e.g. '180 lbs').
height numeric Player height (string e.g. '6-2' or inches).
display_height character Player height in display format (e.g. '6-2').
age integer Player age (in years).
date_of_birth character Date of birth (YYYY-MM-DD).
slug character URL-safe identifier.
headshot_href character Headshot image URL.
headshot_alt character Alternative-text label for the headshot.
jersey character Jersey number worn by the player.
position_id integer Unique position identifier.
position_name character Listed roster position ('Guard', 'Forward', 'Center').
position_display_name character Position display name.
position_abbreviation character Position abbreviation ('G' / 'F' / 'C').
position_leaf logical Position leaf.
linked logical TRUE if the record is linked to a related entity.
years integer Years.
active logical TRUE if the row represents an active record (player / team / season).
contract_x_ref character Contract x ref.
contract_bird_status integer Contract bird status.
contract_active logical Contract active.
contract_active_1 logical Contract active 1.
contract_incoming_trade_value integer Contract incoming trade value.
contract_outgoing_trade_value integer Contract outgoing trade value.
contract_minimum_salary_exception logical Contract minimum salary exception.
contract_option_type integer Contract option type.
contract_salary integer Contract salary.
contract_salary_remaining integer Contract salary remaining.
contract_years_remaining integer Contract years remaining.
contract_x_ref_1 character Contract x ref 1.
contract_x_ref_2 character Contract x ref 2.
contract_trade_kicker_active logical Contract trade kicker active.
contract_trade_kicker_percentage numeric Contract trade kicker percentage (0-1 decimal).
contract_trade_kicker_value integer Contract trade kicker value.
contract_trade_kicker_trade_value integer Contract trade kicker trade value.
contract_trade_restriction logical Contract trade restriction.
contract_unsigned_foreign_pick logical Contract unsigned foreign pick.
contract_active_2 logical Contract active 2.
draft_display_text character Draft display text.
draft_round integer Round of the draft selection.
draft_year integer Draft year (4-digit).
draft_selection integer Draft selection.
draft_x_ref character Draft x ref.
draft_x_ref_1 character Draft x ref 1.
status_id integer Status identifier.
status_name character Status label.
status_type character Status type.
status_abbreviation character Status abbreviation.
defensive_blocks numeric Short for blocked shot, number of times when a defensive player legally deflects a field goal attempt from an offensive player.
defensive_defensive_rebounds numeric The number of times when the defense obtains the possession of the ball after a missed shot by the offense.
defensive_steals numeric The number of times a defensive player forced a turnover by intercepting or deflecting a pass or a dribble of an offensive player.
defensive_def_rebound_rate numeric The percentage of missed shots that a team rebounds defensively. Rebound Rate = (Defensive Rebounds x Team Minutes) divided by (Player Minutes x (Team Defensive Rebounds + Opponent Defensive Rebounds)).
defensive_avg_defensive_rebounds numeric The average defensive rebounds per game.
defensive_avg_blocks numeric The average blocks per game.
defensive_avg_steals numeric The average steals per game.
defensive_avg48defensive_rebounds numeric The average number of defensive rebounds per 48 minutes.
defensive_avg48blocks numeric The average number of blocks per 48 minutes.
defensive_avg48steals numeric The average number of steals per 48 minutes.
defensive_drpm numeric Defensive Real Plus-Minus.
general_disqualifications numeric The number of times a player reached the foul limit.
general_flagrant_fouls numeric The number of fouls that the officials thought were unnecessary or excessive.
general_fouls numeric The number of times a player had illegal contact with the opponent.
general_per numeric A numerical value for each of a player's accomplishments per-minute and is pace-adjusted for the team they play on. The league average in PER to 15.00 every season.
general_rebound_rate numeric The percentage of missed shots that a team rebounds. Rebound Rate = (Rebounds x Team Minutes) divided by (Player Minutes x (Team Rebounds + Opponent Rebounds)).
general_ejections numeric The number of times a player or coach is removed from the game as a result of a serious offense.
general_technical_fouls numeric The number of times an player or coach was called for a technical foul (unsportsmanlike conduct or violations).
general_rebounds numeric The total number of rebounds (offensive and defensive).
general_vorp numeric Value Over Replacement Player.
general_warp numeric Wins Above Replacement Player.
general_rpm numeric Real Plus-Minus.
general_minutes numeric The total number of minutes played.
general_avg_minutes numeric The average number of minutes per game.
general_nba_rating numeric General nba rating.
general_plus_minus numeric A player's estimated on-court impact on team performance measured in point differential per 100 possessions.
general_avg_rebounds numeric The average rebounds per game.
general_avg_fouls numeric The average fouls committed per game.
general_avg_flagrant_fouls numeric The average number of flagrant fouls per game.
general_avg_technical_fouls numeric The average number of technical fouls per game.
general_avg_ejections numeric The average ejections per game.
general_avg_disqualifications numeric The average number of disqualifications per game.
general_assist_turnover_ratio numeric The average number of assists a player or team records per turnover.
general_steal_foul_ratio numeric The average number of steals a player or team records per foul committed.
general_block_foul_ratio numeric The average number of blocks a player or record per foul committed.
general_avg_team_rebounds numeric The average number of rebounds for a team per game.
general_total_rebounds numeric The total number of rebounds for a team or player.
general_total_technical_fouls numeric The total number of technical fouls for a team or player.
general_team_assist_turnover_ratio numeric The number of assists per turnover for a team.
general_steal_turnover_ratio numeric The number of steals per turnover.
general_avg48rebounds numeric The average number of rebounds per 48 minutes.
general_avg48fouls numeric The average number of fouls committed per 48 minutes.
general_avg48flagrant_fouls numeric The average number of flagrant fouls committed per 48 minutes.
general_avg48technical_fouls numeric The average number of technical fouls committed per 48 minutes.
general_avg48ejections numeric The average number of ejections per 48 minutes.
general_avg48disqualifications numeric The average number of disqualifications per 48 minutes.
general_r40 numeric Rebounds Per 40 Minutes.
general_games_played numeric Games Played.
general_games_started numeric The number of games started by an athlete.
general_double_double numeric The number of times double digit values were accumulated in 2 of the following categories: points, rebounds, assists, steals, and blocked shots.
general_triple_double numeric The number of times double digit values were accumulated in 3 of the following categories: points, rebounds, assists, steals, and blocked shots.
offensive_assists numeric The number of times a player who passes the ball to a teammate in a way that leads to a score by field goal, meaning that he or she was "assisting" in the basket. There is some judgment involved in deciding whether a passer should be credited with an assist.
offensive_effective_fg_pct numeric Offensive effective field goals percentage (0-1 decimal).
offensive_field_goals numeric Field Goal makes and attempts.
offensive_field_goals_attempted numeric The number of times a 2pt field goal was attempted.
offensive_field_goals_made numeric The number of times a 2pt field goal was made.
offensive_field_goal_pct numeric The ratio of field goals made to field goals attempted: FGM / FGA.
offensive_free_throws numeric Free Throw makes and attempts.
offensive_free_throw_pct numeric The ratio of free throws made to free throws attempted: FTM / FTA.
offensive_free_throws_attempted numeric The number of times a free throw was attempted.
offensive_free_throws_made numeric The number of times a free throw was made.
offensive_offensive_rebounds numeric The number of times when the offense obtains the possession of the ball after a missed shot.
offensive_points numeric The number of points scored.
offensive_turnovers numeric The number of times a player loses possession to the other team.
offensive_three_point_pct numeric The ratio of 3pt field goals made to 3pt field goals attempted: 3PM / 3PA.
offensive_three_point_field_goals_attempted numeric The number of times a 3pt field goal was attempted.
offensive_three_point_field_goals_made numeric The number of times a 3pt field goal was made.
offensive_true_shooting_pct numeric What a team's shooting percentage would be if we accounted for free throws and 3-pointers. True Shooting Percentage = (Total points x 50) divided by ((FGA + (FTA x 0.44)).
offensive_total_turnovers numeric The number of turnovers plus team turnovers for the team.
offensive_assist_ratio numeric The percentage of a team's possessions that ends in an assist. Assist Ratio = (Assists x 100) divided by ((FGA + (FTA x 0.44) + Assists + Turnovers).
offensive_points_in_paint numeric The amount of points scored in the area known as "the Paint"(the rectangle between the foul line and the baseline).
offensive_off_rebound_rate numeric The percentage of missed shots that a team rebounds offensively. Offensive Rebound Rate = (Offensive Rebounds x Team Minutes) divided by (Player Minutes x (Team Offensive Rebounds + Opponent Defensive Rebounds)).
offensive_turnover_ratio numeric The percentage of a team's possessions that end in a turnover. Turnover Ratio = (Turnover x 100) divided by ((FGA + (FTA x 0.44) + Assists + Turnovers).
offensive_brick_index numeric How many points a player costs his team with his shooting compared with the league average on a per-40-minute basis. ((52.8 - TS%) x (FGA + (FTA x 0.44))) / (Min/40) .
offensive_usage_rate numeric the number of possessions a player uses per 40 minutes. Usage Rate = ((FGA + (FT Att. x 0.44) + (Ast x 0.33) + TO) x 40 x League Pace) divided by (Minutes x Team Pace).
offensive_avg_field_goals_made numeric The average field goals made per game.
offensive_avg_field_goals_attempted numeric The average field goals attempted per game.
offensive_avg_three_point_field_goals_made numeric The average three point field goals made per game.
offensive_avg_three_point_field_goals_attempted numeric The average three point field goals attempted per game.
offensive_avg_free_throws_made numeric The average free throw shots made per game.
offensive_avg_free_throws_attempted numeric The average free throw shots attempted per game.
offensive_avg_points numeric The average number of points scored per game.
offensive_avg_offensive_rebounds numeric The average offensive rebounds per game.
offensive_avg_assists numeric The average assists per game.
offensive_avg_turnovers numeric The average turnovers committed per game.
offensive_offensive_rebound_pct numeric The percentage of the number of times they obtain the possession of the ball after a missed shot.
offensive_estimated_possessions numeric An estimation of the number of possessions for a team or player.
offensive_avg_estimated_possessions numeric The average number of estimated possessions per game for a team or player.
offensive_points_per_estimated_possessions numeric The number of points per estimated possession for a team or player.
offensive_avg_team_turnovers numeric The average number of turnovers for a team per game.
offensive_avg_total_turnovers numeric The average number of total turnovers for a team per game.
offensive_three_point_field_goal_pct numeric The ratio of 3pt field goals made to 3pt field goals attempted: 3PM / 3PA.
offensive_two_point_field_goals_made numeric The number of 2-point field goals made for a team or player.
offensive_two_point_field_goals_attempted numeric The number of 2-point field goals attempted for a team or player.
offensive_avg_two_point_field_goals_made numeric The number of 2-point field goals made per game for a team or player.
offensive_avg_two_point_field_goals_attempted numeric The number of 2-point field goals attempted per game for a team or player.
offensive_two_point_field_goal_pct numeric The percentage of 2-points fields goals made by a team or player.
offensive_shooting_efficiency numeric The efficiency with which a team or player shoots the basketball.
offensive_scoring_efficiency numeric The efficiency with which a team or player scores the basketball.
offensive_avg48field_goals_made numeric The average number of fieldgoals made per 48 minutes.
offensive_avg48field_goals_attempted numeric The average number of fieldgoals attempted per 48 minutes.
offensive_avg48three_point_field_goals_made numeric The average per number of 3-Pointers made per 48 minutes.
offensive_avg48three_point_field_goals_attempted numeric The average number of 3-pointers attempted per 48 minutes.
offensive_avg48free_throws_made numeric The average number of Free Throws made per 48 minutes.
offensive_avg48free_throws_attempted numeric The average number of free throws attempted per 48 minutes.
offensive_avg48points numeric The average number of points scored per 48 minutes.
offensive_avg48offensive_rebounds numeric The average number of offenseive rebounds per 48 minutes.
offensive_avg48assists numeric The average number of assists per 48 minutes.
offensive_avg48turnovers numeric The average number of turnovers per 48 minutes.
offensive_p40 numeric Points Per 40 Minutes.
offensive_a40 numeric Assists Per 40 Minutes.
offensive_orpm numeric Offensive Real Plus-Minus.
team_id integer Unique team identifier.
team_guid character ESPN team GUID.
team_uid character ESPN universal team identifier (UID format 's:40~l:...~t:...').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
team_location character Team city or location string.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_abbreviation character Short team abbreviation (e.g. 'LAS').
team_display_name character Full team display name.
team_short_display_name character Short team display name (e.g. 'Aces').
team_color character Team primary color (hex without leading '#').
team_alternate_color character Team alternate color (hex without leading '#').
team_is_active logical TRUE if the team is currently active.
team_is_all_star logical TRUE if the row represents an All-Star team.
logo_href character Team or league logo URL.
logo_dark_href character Logo URL for dark backgrounds.
logos_href_2 character Logos href 2.
logos_href_3 character Logos href 3.

Author(s)

Saiem Gilani

See Also

Other ESPN MBB Functions: espn_mbb_athletes_index(), espn_mbb_award(), espn_mbb_calendar(), espn_mbb_coach(), espn_mbb_coach_record(), espn_mbb_coach_season(), espn_mbb_coaches(), espn_mbb_conferences(), espn_mbb_franchise(), espn_mbb_franchises(), espn_mbb_futures(), espn_mbb_game_all(), espn_mbb_game_odds(), espn_mbb_game_official_detail(), espn_mbb_game_play(), espn_mbb_game_play_personnel(), espn_mbb_game_player_box(), espn_mbb_game_probabilities(), espn_mbb_game_propbets(), espn_mbb_game_team_linescores(), espn_mbb_game_team_roster_entry(), espn_mbb_injuries(), espn_mbb_leaders(), espn_mbb_news(), espn_mbb_player_awards(), espn_mbb_player_career_stats(), espn_mbb_player_eventlog_v2(), espn_mbb_player_info(), espn_mbb_player_overview(), espn_mbb_player_seasons(), espn_mbb_position(), espn_mbb_positions(), espn_mbb_powerindex(), espn_mbb_rankings(), espn_mbb_scoreboard(), espn_mbb_season_awards(), espn_mbb_season_group(), espn_mbb_season_groups(), espn_mbb_season_info(), espn_mbb_season_leaders(), espn_mbb_season_ranking(), espn_mbb_season_rankings(), espn_mbb_season_type(), espn_mbb_season_types(), espn_mbb_season_week(), espn_mbb_season_weeks(), espn_mbb_seasons(), espn_mbb_standings(), espn_mbb_team(), espn_mbb_team_current_roster(), espn_mbb_team_injuries(), espn_mbb_team_news(), espn_mbb_team_odds_records(), espn_mbb_team_record(), espn_mbb_team_record_detail(), espn_mbb_team_schedule(), espn_mbb_team_season_roster(), espn_mbb_team_season_statistics(), espn_mbb_team_stats(), espn_mbb_teams(), espn_mbb_tournament(), espn_mbb_tournament_season(), espn_mbb_tournament_seasons(), espn_mbb_tournaments(), espn_mbb_venues(), espn_mbb_week_ranking(), espn_mbb_week_rankings(), espn_mbb_wp()

Other ESPN NBA Functions: espn_mbb_athletes_index(), espn_mbb_award(), espn_mbb_calendar(), espn_mbb_coach(), espn_mbb_coach_record(), espn_mbb_coach_season(), espn_mbb_coaches(), espn_mbb_conferences(), espn_mbb_franchise(), espn_mbb_franchises(), espn_mbb_futures(), espn_mbb_game_all(), espn_mbb_game_odds(), espn_mbb_game_official_detail(), espn_mbb_game_play(), espn_mbb_game_play_personnel(), espn_mbb_game_player_box(), espn_mbb_game_probabilities(), espn_mbb_game_propbets(), espn_mbb_game_team_linescores(), espn_mbb_game_team_roster_entry(), espn_mbb_injuries(), espn_mbb_leaders(), espn_mbb_news(), espn_mbb_player_awards(), espn_mbb_player_career_stats(), espn_mbb_player_eventlog_v2(), espn_mbb_player_info(), espn_mbb_player_overview(), espn_mbb_player_seasons(), espn_mbb_position(), espn_mbb_positions(), espn_mbb_powerindex(), espn_mbb_scoreboard(), espn_mbb_season_awards(), espn_mbb_season_group(), espn_mbb_season_groups(), espn_mbb_season_info(), espn_mbb_season_leaders(), espn_mbb_season_ranking(), espn_mbb_season_rankings(), espn_mbb_season_type(), espn_mbb_season_types(), espn_mbb_season_week(), espn_mbb_season_weeks(), espn_mbb_seasons(), espn_mbb_standings(), espn_mbb_team(), espn_mbb_team_current_roster(), espn_mbb_team_injuries(), espn_mbb_team_news(), espn_mbb_team_odds_records(), espn_mbb_team_record(), espn_mbb_team_record_detail(), espn_mbb_team_schedule(), espn_mbb_team_season_roster(), espn_mbb_team_season_statistics(), espn_mbb_team_stats(), espn_mbb_teams(), espn_mbb_tournament(), espn_mbb_tournament_season(), espn_mbb_tournament_seasons(), espn_mbb_tournaments(), espn_mbb_venues(), espn_mbb_week_ranking(), espn_mbb_week_rankings(), espn_mbb_wp(), espn_nba_draft_pick(), espn_nba_freeagents(), espn_nba_player_contracts(), espn_nba_team_depthchart(), espn_nba_transactions()

Examples


try(espn_mbb_player_stats(athlete_id = 4593919, year = 2021))


try(espn_nba_player_stats(athlete_id = 1966, year = 2022))


hoopR documentation built on Aug. 25, 2026, 9:07 a.m.