espn_mbb_wp: *Men's College Basketball win probability chart data from...

View source: R/espn_mbb_wp.R

espn_mbb_wpR Documentation

Men's College Basketball win probability chart data from ESPN

Description

Men's College Basketball win probability chart data from ESPN

Get NBA win probability chart data from ESPN

Usage

espn_mbb_wp(game_id)

espn_nba_wp(game_id)

Arguments

game_id

(Integer required): Game ID filter for querying a single game

Value

espn_mbb_wp() - A data frame with 9 variables:

col_name type description
game_id character Referencing game ID (should be same as game_id from other functions).
play_id character Referencing play ID.
period integer Clock (time) left in the game.
time_left character Clock (time) left in the game.
period_seconds_left integer Seconds left in the period.
game_seconds_left integer Seconds left in the game.
home_win_percentage double The probability of the home team winning the game.
away_win_percentage double The probability of the away team winning the game (calculated as 1 - home_win_percentage - tie_percentage).
tie_percentage double The probability of the game ending the final period in a tie.

espn_nba_wp() - A data frame with 21 variables:

col_name types description
game_id numeric Unique game identifier.
play_id character Unique play identifier within a game.
home_win_percentage numeric Home win percentage (0-1 decimal).
away_win_percentage numeric Away win percentage (0-1 decimal).
tie_percentage numeric Tie percentage (0-1 decimal).
sequence_number character Sequence number representing a shot-possession (V3 PBP).
text character Text description of the play / record.
away_score integer Away team score at the time of the play.
home_score integer Home team score at the time of the play.
scoring_play logical TRUE if the play resulted in points scored.
score_value integer Point value of the play (2 / 3 / 1).
participants list Participants.
shooting_play logical TRUE if the play was a shooting attempt.
type_id character Type identifier (numeric).
type_text character Display text for the type field.
period_number integer Numeric period (1-4 for quarters; 5+ for OT).
period_display_value character Period display label (e.g. '1st Quarter', 'OT').
clock_display_value character Game clock display string (e.g. '8:32').
team_id character Unique team identifier.
coordinate_x integer X coordinate on the court (half-court layout).
coordinate_y integer Y coordinate on the court (half-court layout).

See Also

Other ESPN MBB Functions: espn_mbb_athletes_index(), espn_mbb_award(), espn_mbb_calendar(), espn_mbb_coach(), espn_mbb_coach_record(), espn_mbb_coach_season(), espn_mbb_coaches(), espn_mbb_conferences(), espn_mbb_franchise(), espn_mbb_franchises(), espn_mbb_futures(), espn_mbb_game_all(), espn_mbb_game_odds(), espn_mbb_game_official_detail(), espn_mbb_game_play(), espn_mbb_game_play_personnel(), espn_mbb_game_player_box(), espn_mbb_game_probabilities(), espn_mbb_game_propbets(), espn_mbb_game_team_linescores(), espn_mbb_game_team_roster_entry(), espn_mbb_injuries(), espn_mbb_leaders(), espn_mbb_news(), espn_mbb_player_awards(), espn_mbb_player_career_stats(), espn_mbb_player_eventlog_v2(), espn_mbb_player_info(), espn_mbb_player_overview(), espn_mbb_player_seasons(), espn_mbb_player_stats(), espn_mbb_position(), espn_mbb_positions(), espn_mbb_powerindex(), espn_mbb_rankings(), espn_mbb_scoreboard(), espn_mbb_season_awards(), espn_mbb_season_group(), espn_mbb_season_groups(), espn_mbb_season_info(), espn_mbb_season_leaders(), espn_mbb_season_ranking(), espn_mbb_season_rankings(), espn_mbb_season_type(), espn_mbb_season_types(), espn_mbb_season_week(), espn_mbb_season_weeks(), espn_mbb_seasons(), espn_mbb_standings(), espn_mbb_team(), espn_mbb_team_current_roster(), espn_mbb_team_injuries(), espn_mbb_team_news(), espn_mbb_team_odds_records(), espn_mbb_team_record(), espn_mbb_team_record_detail(), espn_mbb_team_schedule(), espn_mbb_team_season_roster(), espn_mbb_team_season_statistics(), espn_mbb_team_stats(), espn_mbb_teams(), espn_mbb_tournament(), espn_mbb_tournament_season(), espn_mbb_tournament_seasons(), espn_mbb_tournaments(), espn_mbb_venues(), espn_mbb_week_ranking(), espn_mbb_week_rankings()

Other ESPN NBA Functions: espn_mbb_athletes_index(), espn_mbb_award(), espn_mbb_calendar(), espn_mbb_coach(), espn_mbb_coach_record(), espn_mbb_coach_season(), espn_mbb_coaches(), espn_mbb_conferences(), espn_mbb_franchise(), espn_mbb_franchises(), espn_mbb_futures(), espn_mbb_game_all(), espn_mbb_game_odds(), espn_mbb_game_official_detail(), espn_mbb_game_play(), espn_mbb_game_play_personnel(), espn_mbb_game_player_box(), espn_mbb_game_probabilities(), espn_mbb_game_propbets(), espn_mbb_game_team_linescores(), espn_mbb_game_team_roster_entry(), espn_mbb_injuries(), espn_mbb_leaders(), espn_mbb_news(), espn_mbb_player_awards(), espn_mbb_player_career_stats(), espn_mbb_player_eventlog_v2(), espn_mbb_player_info(), espn_mbb_player_overview(), espn_mbb_player_seasons(), espn_mbb_player_stats(), espn_mbb_position(), espn_mbb_positions(), espn_mbb_powerindex(), espn_mbb_scoreboard(), espn_mbb_season_awards(), espn_mbb_season_group(), espn_mbb_season_groups(), espn_mbb_season_info(), espn_mbb_season_leaders(), espn_mbb_season_ranking(), espn_mbb_season_rankings(), espn_mbb_season_type(), espn_mbb_season_types(), espn_mbb_season_week(), espn_mbb_season_weeks(), espn_mbb_seasons(), espn_mbb_standings(), espn_mbb_team(), espn_mbb_team_current_roster(), espn_mbb_team_injuries(), espn_mbb_team_news(), espn_mbb_team_odds_records(), espn_mbb_team_record(), espn_mbb_team_record_detail(), espn_mbb_team_schedule(), espn_mbb_team_season_roster(), espn_mbb_team_season_statistics(), espn_mbb_team_stats(), espn_mbb_teams(), espn_mbb_tournament(), espn_mbb_tournament_season(), espn_mbb_tournament_seasons(), espn_mbb_tournaments(), espn_mbb_venues(), espn_mbb_week_ranking(), espn_mbb_week_rankings(), espn_nba_draft_pick(), espn_nba_freeagents(), espn_nba_player_contracts(), espn_nba_team_depthchart(), espn_nba_transactions()

Examples


espn_mbb_wp(game_id = 401256760)



espn_nba_wp(game_id = 401283399)



hoopR documentation built on Aug. 25, 2026, 9:07 a.m.