kp_confhistory: *Get KenPom's historical conference ratings*

View source: R/kp_historical_tables.R

kp_confhistoryR Documentation

Get KenPom's historical conference ratings

Description

Get KenPom's historical conference ratings

Usage

kp_confhistory(conf)

Arguments

conf

Used to limit to players in a specific conference.

Allowed values are: 'A10', 'ACC', 'AE', 'AMER', 'ASUN', 'B10', 'B12', 'BE', 'BSKY', 'BSTH', 'BW', 'CAA', 'CUSA', 'HORZ', 'IND', IVY', 'MAAC', 'MAC', 'MEAC', 'MVC', 'MWC', 'NEC', 'OVC', 'P12', 'PAT', 'SB', 'SC', 'SEC', 'SLND', 'SUM', 'SWAC', 'WAC', 'WCC'.

If you try to use a conference that doesn't exist for a given season, like 'IND' and '2018', you'll get an empty table, as kenpom.com doesn't serve 404 pages for invalid table queries like that. No filter applied by default.

Value

A data frame with the following columns:

col_name types description
year integer 4-digit year.
rank character Rank.
tempo numeric Tempo.
efficiency numeric Efficiency.
e_fg_pct numeric E field goals percentage (0-1 decimal).
to_pct numeric To percentage (0-1 decimal).
or_pct numeric Or percentage (0-1 decimal).
ft_rate numeric Ft rate.
fg_2_pct numeric Field goals 2 percentage (0-1 decimal).
fg_3_pct numeric Field goals 3 percentage (0-1 decimal).
ft_pct numeric Free throw percentage (0-1).
fg_3a_pct numeric Field goals 3a percentage (0-1 decimal).
a_pct numeric A percentage (0-1 decimal).
blk_pct numeric Blocks percentage (0-1 decimal).
stl_pct numeric Steals percentage (0-1 decimal).
home_record character Home win-loss record.
bids character Bids.
s16 character S16.
f4 character F4.
ch character Ch.
reg_season_champ character Reg season champ.
tourney_champ character Tourney champ.
best_team character Best team.

See Also

Other KenPom Historical Functions: kp_coach_history(), kp_conf(), kp_confstats(), kp_pomeroy_archive_ratings(), kp_program_ratings(), kp_team_history()

Examples


  try(kp_confhistory(conf = 'ACC'))


hoopR documentation built on Aug. 25, 2026, 9:07 a.m.