| nba_assist_pct | R Documentation |
Estimated percentage of teammate field goals a player assisted while on the floor.
nba_assist_pct(ast, fgm, minutes, team_fgm, team_minutes)
ast, fgm, minutes |
Player totals: assists, field goals made, minutes. |
team_fgm, team_minutes |
Team field goals made and minutes for the same game(s). |
A numeric vector of assist percentages (0-100 scale).
Other Basketball Analytics Utilities:
espn_basketball_player_core(),
nba_add_advanced_metrics(),
nba_assist_to_turnover(),
nba_defensive_rating(),
nba_effective_fg_pct(),
nba_four_factors(),
nba_ft_rate(),
nba_game_score(),
nba_net_rating(),
nba_offensive_rating(),
nba_oreb_pct(),
nba_pace(),
nba_per_minutes(),
nba_per_possessions(),
nba_possessions(),
nba_true_shooting_pct(),
nba_turnover_pct(),
nba_usage_rate()
nba_assist_pct(ast = 8, fgm = 10, minutes = 36, team_fgm = 40, team_minutes = 240)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.