realgm_future_free_agents: *RealGM Future NBA Free Agents*

View source: R/realgm_players.R

realgm_future_free_agentsR Documentation

RealGM Future NBA Free Agents

Description

Get RealGM's projected future NBA free-agent class from RealGM.

One row per upcoming free agent, including the free-agency season, the player's Bird/veteran free-agent status, recent production and – distinctively – the player's listed agent.

Requires a headless browser (see realgm_players()).

Usage

realgm_future_free_agents()

Value

A hoopR_data tibble with one row per future free agent:

col_name types description
player character Player name.
pos character Position.
team character Current team abbreviation.
season character Free-agency season (e.g. 2026-2027).
age integer Age.
yos integer Years of service.
veteran_fa_status character Bird / Non-Bird / veteran FA status.
gp integer Games played.
pts numeric Points per game.
reb numeric Rebounds per game.
ast numeric Assists per game.
per numeric Player Efficiency Rating.
agent character Listed player agent.

See Also

Other RealGM Functions: realgm_coaches(), realgm_draft(), realgm_draft_prospects(), realgm_early_entry(), realgm_gms(), realgm_individual_games(), realgm_individual_seasons(), realgm_player_stats(), realgm_players(), realgm_players_abroad(), realgm_rookie_scale(), realgm_salary_cap(), realgm_standings(), realgm_team_stats(), realgm_teams(), realgm_transactions()

Examples

## Not run: 
  try(realgm_future_free_agents())

## End(Not run)

hoopR documentation built on Aug. 25, 2026, 9:07 a.m.