realgm_standings: *RealGM NBA Standings*

View source: R/realgm_standings.R

realgm_standingsR Documentation

RealGM NBA Standings

Description

Get the current NBA standings (both conferences) from RealGM.

One row per team with record, win pct, games back, streak, last-ten, scoring margin and home/away/division/conference splits. The Eastern and Western conference tables are stacked and labelled by a conference column.

Requires a headless browser (see realgm_players()).

Usage

realgm_standings()

Value

A hoopR_data tibble with one row per team:

col_name types description
number integer Conference rank.
team character Team name.
w integer Wins.
l integer Losses.
pct numeric Win percentage.
gb numeric Games back.
l10 character Last-ten record.
strk character Current streak.
ppg numeric Points per game.
oppg numeric Opponent points per game.
diff numeric Scoring margin.
home character Home record.
away character Away record.
conference character Eastern or Western.

See Also

Other RealGM Functions: realgm_coaches(), realgm_draft(), realgm_draft_prospects(), realgm_early_entry(), realgm_future_free_agents(), realgm_gms(), realgm_individual_games(), realgm_individual_seasons(), realgm_player_stats(), realgm_players(), realgm_players_abroad(), realgm_rookie_scale(), realgm_salary_cap(), realgm_team_stats(), realgm_teams(), realgm_transactions()

Examples

## Not run: 
  try(realgm_standings())

## End(Not run)

hoopR documentation built on Aug. 25, 2026, 9:07 a.m.