View source: R/cbbd_substitutions.R
| cbbd_substitutions_game | R Documentation |
Get substitution data for a single game from the CollegeBasketballData API.
Get substitution data for a single player from the CollegeBasketballData API.
Get substitution data for a team-season from the CollegeBasketballData API.
cbbd_substitutions_game(game_id)
cbbd_substitutions_player(player_id, season = most_recent_mbb_season())
cbbd_substitutions_team(season = most_recent_mbb_season(), team)
game_id |
(integer required): CollegeBasketballData game id. See
|
player_id |
(integer required): Athlete id. |
season |
(integer required): Season, 4-digit ending-year (e.g. |
team |
(character required): Team name (e.g. |
A hoopR_data tibble with one row per substitution. sub_in and
sub_out objects are flattened to sub_in_* / sub_out_* columns:
| col_name | types | description |
| game_id | integer | Game id. |
| start_date | character | Game start date (ISO 8601). |
| team_id | integer | Team id. |
| team | character | Team name. |
| conference | character | Team conference. |
| athlete_id | integer | Athlete id. |
| athlete | character | Athlete name. |
| position | character | Athlete position. |
| opponent_id | integer | Opponent team id. |
| opponent | character | Opponent team name. |
| opponent_conference | character | Opponent conference. |
A hoopR_data tibble with one row per substitution (same columns as
cbbd_substitutions_game()).
A hoopR_data tibble with one row per substitution (same columns as
cbbd_substitutions_game()).
try(cbbd_substitutions_game(game_id = 5881))
try(cbbd_substitutions_player(player_id = 160, season = 2024))
try(cbbd_substitutions_team(season = 2024, team = "Duke"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.