| .realgm_html | R Documentation |
Navigates headless Chrome to the page, waits for the Cloudflare challenge to
resolve (the page title stops being "Just a moment..."), and returns the
fully rendered HTML for rvest parsing.
.realgm_html(path, wait = 25)
path |
Page path beginning with |
wait |
Maximum seconds to wait for the challenge to clear. |
The rendered page HTML as a character string.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.