Learn R Programming

hoopR (version 3.1.0)

espn_mbb_player_overview: Get ESPN Women's College Basketball Athlete Overview

Description

Get ESPN Women's College Basketball Athlete Overview

Get ESPN Women's College Basketball Athlete Overview

Get ESPN Women's College Basketball Athlete Stats

Get ESPN Women's College Basketball Athlete Gamelog

Get ESPN Women's College Basketball Athlete Splits

Get ESPN Women's College Basketball Athlete Eventlog

Get ESPN Women's College Basketball Athlete Statisticslog

Get ESPN NBA Athlete Overview

Get ESPN NBA Athlete Overview

Get ESPN NBA Athlete Stats

Get ESPN NBA Athlete Gamelog

Get ESPN NBA Athlete Splits

Get ESPN NBA Athlete Eventlog

Get ESPN NBA Athlete Statisticslog

Usage

espn_mbb_player_overview(athlete_id, season = most_recent_mbb_season(), ...)

espn_mbb_player_stats_v3(athlete_id, season = most_recent_mbb_season(), ...)

espn_mbb_player_gamelog(athlete_id, season = most_recent_mbb_season(), ...)

espn_mbb_player_splits(athlete_id, season = most_recent_mbb_season(), ...)

espn_mbb_player_eventlog(athlete_id, season = most_recent_mbb_season(), ...)

espn_mbb_player_statisticslog( athlete_id, season = most_recent_mbb_season(), ... )

espn_nba_player_overview(athlete_id, season = most_recent_nba_season(), ...)

espn_nba_player_stats_v3(athlete_id, season = most_recent_nba_season(), ...)

espn_nba_player_gamelog(athlete_id, season = most_recent_nba_season(), ...)

espn_nba_player_splits(athlete_id, season = most_recent_nba_season(), ...)

espn_nba_player_eventlog(athlete_id, season = most_recent_nba_season(), ...)

espn_nba_player_statisticslog( athlete_id, season = most_recent_nba_season(), ... )

Value

A named list of data frames: Statistics, NextGame, Last5Games, Headlines, FantasyOutlook.

Statistics

col_nametypesdescription
(varies)character

NextGame

col_nametypesdescription
idcharacterId.
datecharacterDate in YYYY-MM-DD format.
namecharacterDisplay name.
short_namecharacterShort display name.

Last5Games

col_nametypesdescription
(varies)character

Headlines

col_nametypesdescription
headlinecharacterNews headline.
descriptioncharacterLong-form description text.
publishedcharacterPublication timestamp (ISO 8601).

FantasyOutlook

col_nametypesdescription
(varies)character

A named list of per-category tibbles. Default category names are General, Offensive, Defensive, Rebounding, Shooting, Misc. Actual names are driven by the ESPN response; additional categories may appear. Each tibble has columns depending on the category returned by ESPN.

A single tibble with one row per game. Column names reflect the stat labels returned by ESPN and will vary by season and player.

A single long-format tibble. When data are present, columns include at minimum category and split_name, plus per-stat columns driven by ESPN labels.

A single tibble. Per-event statistics.$ref URLs from the ESPN core-v2 API are returned as the character column statistics_ref and are NOT resolved. Similarly, event_ref, competition_ref, and team_ref are returned as character columns.

Columns as documented in the shared espn_mbb_player_eventlog_schema table.

A single tibble. When resolved, each row corresponds to one statistical entry in the core-v2 statistics log, with event_ref and statistics_ref character columns pointing to resolvable ESPN endpoints.

col_nametypesdescription
event_refcharacterReference link to the originating event.
statistics_refcharacter

A named list of data frames: Statistics, NextGame, Last5Games, Headlines, FantasyOutlook.

Statistics

col_nametypesdescription
(varies)character

NextGame

col_nametypesdescription
idcharacterId.
datecharacterDate in YYYY-MM-DD format.
namecharacterDisplay name.
short_namecharacterShort display name.

Last5Games

col_nametypesdescription
(varies)character

Headlines

col_nametypesdescription
headlinecharacterNews headline.
descriptioncharacterLong-form description text.
publishedcharacterPublication timestamp (ISO 8601).

FantasyOutlook

col_nametypesdescription
(varies)character

A named list of per-category tibbles. Default category names are General, Offensive, Defensive, Rebounding, Shooting, Misc. Actual names are driven by the ESPN response; additional categories may appear. Each tibble has columns depending on the category returned by ESPN.

A single tibble with one row per game. Column names reflect the stat labels returned by ESPN and will vary by season and player.

A single long-format tibble. When data are present, columns include at minimum category and split_name, plus per-stat columns driven by ESPN labels.

A single tibble. Per-event statistics.$ref URLs from the ESPN core-v2 API are returned as the character column statistics_ref and are NOT resolved. Similarly, event_ref, competition_ref, and team_ref are returned as character columns.

Columns as documented in the shared espn_mbb_player_eventlog_schema table.

A single tibble. When resolved, each row corresponds to one statistical entry in the core-v2 statistics log, with event_ref and statistics_ref character columns pointing to resolvable ESPN endpoints.

col_nametypesdescription
event_refcharacterReference link to the originating event.
statistics_refcharacter

Arguments

athlete_id

ESPN athlete identifier (character or numeric).

season

Season year (numeric). Defaults to the most recent MBB season.

...

Additional arguments; currently unused.

Author

Saiem Gilani

See Also

Other ESPN MBB Functions: espn_mbb_athletes_index(), espn_mbb_award(), espn_mbb_calendar(), espn_mbb_coach(), espn_mbb_coach_record(), espn_mbb_coach_season(), espn_mbb_coaches(), espn_mbb_conferences(), espn_mbb_franchise(), espn_mbb_franchises(), espn_mbb_futures(), espn_mbb_game_all(), espn_mbb_game_odds(), espn_mbb_game_official_detail(), espn_mbb_game_play(), espn_mbb_game_play_personnel(), espn_mbb_game_player_box(), espn_mbb_game_probabilities(), espn_mbb_game_propbets(), espn_mbb_game_team_linescores(), espn_mbb_game_team_roster_entry(), espn_mbb_injuries(), espn_mbb_leaders(), espn_mbb_news(), espn_mbb_player_awards(), espn_mbb_player_career_stats(), espn_mbb_player_eventlog_v2(), espn_mbb_player_info(), espn_mbb_player_seasons(), espn_mbb_player_stats(), espn_mbb_position(), espn_mbb_positions(), espn_mbb_powerindex(), espn_mbb_rankings(), espn_mbb_scoreboard(), espn_mbb_season_awards(), espn_mbb_season_group(), espn_mbb_season_groups(), espn_mbb_season_info(), espn_mbb_season_leaders(), espn_mbb_season_ranking(), espn_mbb_season_rankings(), espn_mbb_season_type(), espn_mbb_season_types(), espn_mbb_season_week(), espn_mbb_season_weeks(), espn_mbb_seasons(), espn_mbb_standings(), espn_mbb_team(), espn_mbb_team_current_roster(), espn_mbb_team_injuries(), espn_mbb_team_news(), espn_mbb_team_odds_records(), espn_mbb_team_record(), espn_mbb_team_record_detail(), espn_mbb_team_schedule(), espn_mbb_team_season_roster(), espn_mbb_team_season_statistics(), espn_mbb_team_stats(), espn_mbb_teams(), espn_mbb_tournament(), espn_mbb_tournament_season(), espn_mbb_tournament_seasons(), espn_mbb_tournaments(), espn_mbb_venues(), espn_mbb_week_ranking(), espn_mbb_week_rankings(), espn_mbb_wp()

Other ESPN NBA Functions: espn_mbb_athletes_index(), espn_mbb_award(), espn_mbb_calendar(), espn_mbb_coach(), espn_mbb_coach_record(), espn_mbb_coach_season(), espn_mbb_coaches(), espn_mbb_conferences(), espn_mbb_franchise(), espn_mbb_franchises(), espn_mbb_futures(), espn_mbb_game_all(), espn_mbb_game_odds(), espn_mbb_game_official_detail(), espn_mbb_game_play(), espn_mbb_game_play_personnel(), espn_mbb_game_player_box(), espn_mbb_game_probabilities(), espn_mbb_game_propbets(), espn_mbb_game_team_linescores(), espn_mbb_game_team_roster_entry(), espn_mbb_injuries(), espn_mbb_leaders(), espn_mbb_news(), espn_mbb_player_awards(), espn_mbb_player_career_stats(), espn_mbb_player_eventlog_v2(), espn_mbb_player_info(), espn_mbb_player_seasons(), espn_mbb_player_stats(), espn_mbb_position(), espn_mbb_positions(), espn_mbb_powerindex(), espn_mbb_scoreboard(), espn_mbb_season_awards(), espn_mbb_season_group(), espn_mbb_season_groups(), espn_mbb_season_info(), espn_mbb_season_leaders(), espn_mbb_season_ranking(), espn_mbb_season_rankings(), espn_mbb_season_type(), espn_mbb_season_types(), espn_mbb_season_week(), espn_mbb_season_weeks(), espn_mbb_seasons(), espn_mbb_standings(), espn_mbb_team(), espn_mbb_team_current_roster(), espn_mbb_team_injuries(), espn_mbb_team_news(), espn_mbb_team_odds_records(), espn_mbb_team_record(), espn_mbb_team_record_detail(), espn_mbb_team_schedule(), espn_mbb_team_season_roster(), espn_mbb_team_season_statistics(), espn_mbb_team_stats(), espn_mbb_teams(), espn_mbb_tournament(), espn_mbb_tournament_season(), espn_mbb_tournament_seasons(), espn_mbb_tournaments(), espn_mbb_venues(), espn_mbb_week_ranking(), espn_mbb_week_rankings(), espn_mbb_wp(), espn_nba_draft_pick(), espn_nba_freeagents(), espn_nba_player_contracts(), espn_nba_team_depthchart(), espn_nba_transactions()

Examples

Run this code
# \donttest{
  espn_mbb_player_overview(athlete_id = "4593919", season = 2025)
# }
# \donttest{
  espn_mbb_player_stats_v3(athlete_id = "4593919", season = 2025)
# }
# \donttest{
  espn_mbb_player_gamelog(athlete_id = "4593919", season = 2025)
# }
# \donttest{
  espn_mbb_player_splits(athlete_id = "4593919", season = 2025)
# }
# \donttest{
  espn_mbb_player_eventlog(athlete_id = "4593919", season = 2025)
# }
# \donttest{
  espn_mbb_player_statisticslog(athlete_id = "4593919", season = 2025)
# }
# \donttest{
  espn_nba_player_overview(athlete_id = "1966", season = 2024)
# }
# \donttest{
  espn_nba_player_stats_v3(athlete_id = "1966", season = 2024)
# }
# \donttest{
  espn_nba_player_gamelog(athlete_id = "1966", season = 2024)
# }
# \donttest{
  espn_nba_player_splits(athlete_id = "1966", season = 2024)
# }
# \donttest{
  espn_nba_player_eventlog(athlete_id = "1966", season = 2024)
# }
# \donttest{
  espn_nba_player_statisticslog(athlete_id = "1966", season = 2024)
# }

Run the code above in your browser using DataLab