Get ESPN men's college basketball schedule for a specific year
Get ESPN NBA schedule for a specific year
espn_mbb_scoreboard(season)espn_nba_scoreboard(season)
Returns a tibble
| col_name | types | description |
| matchup | character | Matchup. |
| matchup_short | character | Matchup short. |
| season | integer | Season identifier (4-digit year or 'YYYY-YY' string). |
| season_type | integer | Season type (1=pre-season, 2=regular season, 3=postseason, 4=off-season for ESPN; or string label for WNBA Stats). |
| season_slug | character | Season slug. |
| game_id | integer | Unique game identifier. |
| game_uid | character | Game uid. |
| game_date | Date | Game date (YYYY-MM-DD). |
| attendance | integer | Reported attendance. |
| status_name | character | Status label. |
| broadcast_market | character | Broadcast market label (e.g. 'national', 'home'). |
| broadcast_name | character | Broadcast name. |
| start_date | character | Start date (YYYY-MM-DD). |
| game_date_time | POSIXct | Game start date/time (ISO 8601). |
| home_team_name | character | Home team name. |
| home_team_logo | character | Home team logo URL. |
| home_team_abb | character | Home team's team abb. |
| home_team_id | integer | Unique identifier for the home team. |
| home_team_location | character | Home team's team location. |
| home_team_full_name | character | Full home team name (e.g. 'Las Vegas Aces'). |
| home_team_color | character | Home team primary color (hex). |
| home_score | integer | Home team score at the time of the play. |
| home_win | integer | Home team's win. |
| home_record | character | Home win-loss record. |
| away_team_name | character | Away team name. |
| away_team_logo | character | Away team logo URL. |
| away_team_abb | character | Away team's team abb. |
| away_team_id | integer | Unique identifier for the away team. |
| away_team_location | character | Away team's team location. |
| away_team_full_name | character | Full away team name (e.g. 'Las Vegas Aces'). |
| away_team_color | character | Away team primary color (hex). |
| away_score | integer | Away team score at the time of the play. |
| away_win | integer | Away team's win. |
| away_record | character | Away win-loss record. |
Returns a tibble with scoreboard data
| col_name | types | description |
| matchup | character | Matchup. |
| matchup_short | character | Matchup short. |
| season | integer | Season identifier (4-digit year or 'YYYY-YY' string). |
| season_type | integer | Season type (1=pre-season, 2=regular season, 3=postseason, 4=off-season for ESPN; or string label for WNBA Stats). |
| season_slug | character | Season slug. |
| game_id | integer | Unique game identifier. |
| game_uid | character | Game uid. |
| game_date | Date | Game date (YYYY-MM-DD). |
| attendance | integer | Reported attendance. |
| notes | logical | Free-form notes attached to the record. |
| status_name | character | Status label. |
| broadcasts | logical | JSON array of broadcast records. |
| start_date | character | Start date (YYYY-MM-DD). |
| geo_broadcasts | logical | Geo broadcasts. |
| game_date_time | POSIXct | Game start date/time (ISO 8601). |
| home_team_name | character | Home team name. |
| home_team_logo | character | Home team logo URL. |
| home_team_abb | character | Home team's team abb. |
| home_team_id | integer | Unique identifier for the home team. |
| home_team_location | character | Home team's team location. |
| home_team_full_name | character | Full home team name (e.g. 'Las Vegas Aces'). |
| home_team_color | character | Home team primary color (hex). |
| home_score | integer | Home team score at the time of the play. |
| home_win | integer | Home team's win. |
| home_record | character | Home win-loss record. |
| away_team_name | character | Away team name. |
| away_team_logo | character | Away team logo URL. |
| away_team_abb | character | Away team's team abb. |
| away_team_id | integer | Unique identifier for the away team. |
| away_team_location | character | Away team's team location. |
| away_team_full_name | character | Full away team name (e.g. 'Las Vegas Aces'). |
| away_team_color | character | Away team primary color (hex). |
| away_score | integer | Away team score at the time of the play. |
| away_win | integer | Away team's win. |
| away_record | character | Away win-loss record. |
Either numeric or character
Other ESPN MBB Functions:
espn_mbb_athletes_index(),
espn_mbb_award(),
espn_mbb_calendar(),
espn_mbb_coach(),
espn_mbb_coach_record(),
espn_mbb_coach_season(),
espn_mbb_coaches(),
espn_mbb_conferences(),
espn_mbb_franchise(),
espn_mbb_franchises(),
espn_mbb_futures(),
espn_mbb_game_all(),
espn_mbb_game_odds(),
espn_mbb_game_official_detail(),
espn_mbb_game_play(),
espn_mbb_game_play_personnel(),
espn_mbb_game_player_box(),
espn_mbb_game_probabilities(),
espn_mbb_game_propbets(),
espn_mbb_game_team_linescores(),
espn_mbb_game_team_roster_entry(),
espn_mbb_injuries(),
espn_mbb_leaders(),
espn_mbb_news(),
espn_mbb_player_awards(),
espn_mbb_player_career_stats(),
espn_mbb_player_eventlog_v2(),
espn_mbb_player_info(),
espn_mbb_player_overview(),
espn_mbb_player_seasons(),
espn_mbb_player_stats(),
espn_mbb_position(),
espn_mbb_positions(),
espn_mbb_powerindex(),
espn_mbb_rankings(),
espn_mbb_season_awards(),
espn_mbb_season_group(),
espn_mbb_season_groups(),
espn_mbb_season_info(),
espn_mbb_season_leaders(),
espn_mbb_season_ranking(),
espn_mbb_season_rankings(),
espn_mbb_season_type(),
espn_mbb_season_types(),
espn_mbb_season_week(),
espn_mbb_season_weeks(),
espn_mbb_seasons(),
espn_mbb_standings(),
espn_mbb_team(),
espn_mbb_team_current_roster(),
espn_mbb_team_injuries(),
espn_mbb_team_news(),
espn_mbb_team_odds_records(),
espn_mbb_team_record(),
espn_mbb_team_record_detail(),
espn_mbb_team_schedule(),
espn_mbb_team_season_roster(),
espn_mbb_team_season_statistics(),
espn_mbb_team_stats(),
espn_mbb_teams(),
espn_mbb_tournament(),
espn_mbb_tournament_season(),
espn_mbb_tournament_seasons(),
espn_mbb_tournaments(),
espn_mbb_venues(),
espn_mbb_week_ranking(),
espn_mbb_week_rankings(),
espn_mbb_wp()
Other ESPN NBA Functions:
espn_mbb_athletes_index(),
espn_mbb_award(),
espn_mbb_calendar(),
espn_mbb_coach(),
espn_mbb_coach_record(),
espn_mbb_coach_season(),
espn_mbb_coaches(),
espn_mbb_conferences(),
espn_mbb_franchise(),
espn_mbb_franchises(),
espn_mbb_futures(),
espn_mbb_game_all(),
espn_mbb_game_odds(),
espn_mbb_game_official_detail(),
espn_mbb_game_play(),
espn_mbb_game_play_personnel(),
espn_mbb_game_player_box(),
espn_mbb_game_probabilities(),
espn_mbb_game_propbets(),
espn_mbb_game_team_linescores(),
espn_mbb_game_team_roster_entry(),
espn_mbb_injuries(),
espn_mbb_leaders(),
espn_mbb_news(),
espn_mbb_player_awards(),
espn_mbb_player_career_stats(),
espn_mbb_player_eventlog_v2(),
espn_mbb_player_info(),
espn_mbb_player_overview(),
espn_mbb_player_seasons(),
espn_mbb_player_stats(),
espn_mbb_position(),
espn_mbb_positions(),
espn_mbb_powerindex(),
espn_mbb_season_awards(),
espn_mbb_season_group(),
espn_mbb_season_groups(),
espn_mbb_season_info(),
espn_mbb_season_leaders(),
espn_mbb_season_ranking(),
espn_mbb_season_rankings(),
espn_mbb_season_type(),
espn_mbb_season_types(),
espn_mbb_season_week(),
espn_mbb_season_weeks(),
espn_mbb_seasons(),
espn_mbb_standings(),
espn_mbb_team(),
espn_mbb_team_current_roster(),
espn_mbb_team_injuries(),
espn_mbb_team_news(),
espn_mbb_team_odds_records(),
espn_mbb_team_record(),
espn_mbb_team_record_detail(),
espn_mbb_team_schedule(),
espn_mbb_team_season_roster(),
espn_mbb_team_season_statistics(),
espn_mbb_team_stats(),
espn_mbb_teams(),
espn_mbb_tournament(),
espn_mbb_tournament_season(),
espn_mbb_tournament_seasons(),
espn_mbb_tournaments(),
espn_mbb_venues(),
espn_mbb_week_ranking(),
espn_mbb_week_rankings(),
espn_mbb_wp(),
espn_nba_draft_pick(),
espn_nba_freeagents(),
espn_nba_player_contracts(),
espn_nba_team_depthchart(),
espn_nba_transactions()
# Get schedule from date 2022-11-17
# \donttest{
try(espn_mbb_scoreboard(season = "20221117"))
# }
# Get schedule from date 2022-11-17 (returns 1000 results, max allowable.)
# \donttest{
try(espn_nba_scoreboard(season = 20230423))
# }
Run the code above in your browser using DataLab