Learn R Programming

hoopR (version 3.1.0)

kp_conf: Get KenPom's conference-wide stats

Description

Get KenPom's conference-wide stats

Usage

kp_conf(year, conf)

Value

A list of named data frames:

Standings

col_nametypesdescription
teamcharacterTeam-side label or team identifier.
overallcharacterOverall.
confcharactercharacter.
adj_emnumericAdj em.
adj_em_rknumericAdj em rk.
adj_onumericAdj o.
adj_o_rknumericAdj o rk.
adj_dnumericAdj d.
adj_d_rknumericAdj d rk.
adj_tnumericAdj t.
adj_t_rknumericAdj t rk.
conf_sosnumericConf sos.
conf_sos_rknumericConf sos rk.
next_gamecharacterNext game date or opponent.
yearnumeric4-digit year.

ConferencePlayOffense

col_nametypesdescription
teamcharacterTeam-side label or team identifier.
oenumericOe.
oe_rknumericOe rk.
e_fg_pctnumericE field goals percentage (0-1 decimal).
e_fg_pct_rknumericE fg pct rk.
to_pctnumericTo percentage (0-1 decimal).
to_pct_rknumericTo pct rk.
or_pctnumericOr percentage (0-1 decimal).
or_pct_rknumericOr pct rk.
ft_ratenumericFt rate.
ft_rate_rknumericFt rate rk.
fg_2_pctnumericField goals 2 percentage (0-1 decimal).
fg_2_pct_rknumericFg 2 pct rk.
fg_3_pctnumericField goals 3 percentage (0-1 decimal).
fg_3_pct_rknumericFg 3 pct rk.
ft_pctnumericFree throw percentage (0-1).
ft_pct_rknumericFt pct rk.
temponumericTempo.
tempo_rknumericTempo rk.
yearnumeric4-digit year.

ConferencePlayDefense

col_nametypesdescription
teamcharacterTeam-side label or team identifier.
denumericDe.
de_rknumericDe rk.
e_fg_pctnumericE field goals percentage (0-1 decimal).
e_fg_pct_rknumericE fg pct rk.
to_pctnumericTo percentage (0-1 decimal).
to_pct_rknumericTo pct rk.
or_pctnumericOr percentage (0-1 decimal).
or_pct_rknumericOr pct rk.
ft_ratenumericFt rate.
ft_rate_rknumericFt rate rk.
fg_2_pctnumericField goals 2 percentage (0-1 decimal).
fg_2_pct_rknumericFg 2 pct rk.
fg_3_pctnumericField goals 3 percentage (0-1 decimal).
fg_3_pct_rknumericFg 3 pct rk.
blk_pctnumericBlocks percentage (0-1 decimal).
blk_pct_rknumericBlk pct rk.
stl_pctnumericSteals percentage (0-1 decimal).
stl_pct_rknumericStl pct rk.
yearnumeric4-digit year.

AllKenPom

col_nametypesdescription
rkintegerRk.
playercharacterPlayer.
yearnumeric4-digit year.

ConferenceAggregateStats

col_nametypesdescription
statcharacterStat.
valuenumericNumeric or string value field.
rknumericRk.
yearnumeric4-digit year.

WinningTrends

col_nametypesdescription
statcharacterStat.
countcharacterCount of count.
valuenumericNumeric or string value field.
rknumericRk.
yearnumeric4-digit year.

ConferenceComparison

col_nametypesdescription
rknumericRk.
conferencecharacterConference.
ratingnumericRating.
yearnumeric4-digit year.

Arguments

year

Year (YYYY)

conf

Used to limit to players in a specific conference. Allowed values are: 'A10', 'ACC', 'AE', 'AMER',
'ASUN', 'B10', 'B12', 'BE', 'BSKY', 'BSTH', 'BW', 'CAA', 'CUSA', 'HORZ', 'IND', IVY',
'MAAC', 'MAC', 'MEAC', 'MVC', 'MWC', 'NEC', 'OVC', 'P12', 'PAT', 'SB', 'SC', 'SEC', 'SLND',
'SUM', 'SWAC', 'WAC', 'WCC'.
If you try to use a conference that doesn't exist for a given season, like 'IND' and '2018',
you'll get an empty table, as kenpom.com doesn't serve 404 pages for invalid table queries like that.
No filter applied by default.

See Also

Other KenPom Historical Functions: kp_coach_history(), kp_confhistory(), kp_confstats(), kp_pomeroy_archive_ratings(), kp_program_ratings(), kp_team_history()

Examples

Run this code
# \donttest{
    try(kp_conf(year = 2020, conf = 'ACC'))
# }

Run the code above in your browser using DataLab