Learn R Programming

hoopR (version 3.1.0)

kp_confhistory: Get KenPom's historical conference ratings

Description

Get KenPom's historical conference ratings

Usage

kp_confhistory(conf)

Value

A data frame with the following columns:

col_nametypesdescription
yearinteger4-digit year.
rankcharacterRank.
temponumericTempo.
efficiencynumericEfficiency.
e_fg_pctnumericE field goals percentage (0-1 decimal).
to_pctnumericTo percentage (0-1 decimal).
or_pctnumericOr percentage (0-1 decimal).
ft_ratenumericFt rate.
fg_2_pctnumericField goals 2 percentage (0-1 decimal).
fg_3_pctnumericField goals 3 percentage (0-1 decimal).
ft_pctnumericFree throw percentage (0-1).
fg_3a_pctnumericField goals 3a percentage (0-1 decimal).
a_pctnumericA percentage (0-1 decimal).
blk_pctnumericBlocks percentage (0-1 decimal).
stl_pctnumericSteals percentage (0-1 decimal).
home_recordcharacterHome win-loss record.
bidscharacterBids.
s16characterS16.
f4characterF4.
chcharacterCh.
reg_season_champcharacterReg season champ.
tourney_champcharacterTourney champ.
best_teamcharacterBest team.

Arguments

conf

Used to limit to players in a specific conference.

Allowed values are: 'A10', 'ACC', 'AE', 'AMER', 'ASUN', 'B10', 'B12', 'BE', 'BSKY', 'BSTH', 'BW', 'CAA', 'CUSA', 'HORZ', 'IND', IVY', 'MAAC', 'MAC', 'MEAC', 'MVC', 'MWC', 'NEC', 'OVC', 'P12', 'PAT', 'SB', 'SC', 'SEC', 'SLND', 'SUM', 'SWAC', 'WAC', 'WCC'.

If you try to use a conference that doesn't exist for a given season, like 'IND' and '2018', you'll get an empty table, as kenpom.com doesn't serve 404 pages for invalid table queries like that. No filter applied by default.

See Also

Other KenPom Historical Functions: kp_coach_history(), kp_conf(), kp_confstats(), kp_pomeroy_archive_ratings(), kp_program_ratings(), kp_team_history()

Examples

Run this code
# \donttest{
  try(kp_confhistory(conf = 'ACC'))
# }

Run the code above in your browser using DataLab