View source: R/rotowire_injuries.R
| rotowire_injuries | R Documentation |
Get the current NBA injury report from RotoWire.
One row per injured player with team, position, the injury, the current
designation (Out / Doubtful / Questionable / GTD / Day-To-Day) and a link to
the player's RotoWire page. The projected return date is RotoWire
subscriber-only content and is returned as NA for non-subscribers.
This is the live replacement for the defunct RotoWorld injuries feed. See also
bref_injuries() for the Basketball-Reference injury report.
rotowire_injuries()
A hoopR_data tibble with one row per injured player:
| col_name | types | description |
| player_id | character | RotoWire player id. |
| player | character | Player name. |
| first_name | character | First name. |
| last_name | character | Last name. |
| team | character | Team abbreviation. |
| position | character | Position. |
| injury | character | Injury (body part / description). |
| status | character | Injury designation (Out, GTD, Questionable, ...). |
| return_date | character | Projected return (NA unless a subscriber). |
| url | character | RotoWire player page URL. |
try(rotowire_injuries())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.